package Guard::State::Washington;

use 5.006;
use strict;
use warnings;

=head1 NAME

Guard::State::Washington - The great new Guard::State::Washington!

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use Guard::State::Washington;

    my $foo = Guard::State::Washington->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
}

=head1 AUTHOR

C.J. Adams-Collier, C<< <cjac at uw.edu> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-guard-state-washington at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Guard-State-Washington>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Guard::State::Washington


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Guard-State-Washington>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Guard-State-Washington>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Guard-State-Washington>

=item * Search CPAN

L<http://search.cpan.org/dist/Guard-State-Washington/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2012 C.J. Adams-Collier.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.


=cut

1; # End of Guard::State::Washington
